==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressCPUSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressCPUSpecFluent<A extends StressCPUSpecFluent<A>> extends BaseFluent<A>{
  public StressCPUSpecFluent() {
  }
  public StressCPUSpecFluent(StressCPUSpec instance) {
    instance = (instance != null ? instance : new StressCPUSpec());

    if (instance != null) {
      this.withLoad(instance.getLoad());
      this.withOptions(instance.getOptions());
      this.withWorkers(instance.getWorkers());
      this.withLoad(instance.getLoad());
      this.withOptions(instance.getOptions());
      this.withWorkers(instance.getWorkers());
    }
  }
  private Integer load;
  private String options;
  private Integer workers;
  public Integer getLoad() {
    return this.load;
  }
  public A withLoad(Integer load) {
    this.load=load; return (A) this;
  }
  public boolean hasLoad() {
    return this.load != null;
  }
  public String getOptions() {
    return this.options;
  }
  public A withOptions(String options) {
    this.options=options; return (A) this;
  }
  public boolean hasOptions() {
    return this.options != null;
  }
  public Integer getWorkers() {
    return this.workers;
  }
  public A withWorkers(Integer workers) {
    this.workers=workers; return (A) this;
  }
  public boolean hasWorkers() {
    return this.workers != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressCPUSpecFluent that = (StressCPUSpecFluent) o;
    if (!java.util.Objects.equals(load, that.load)) return false;

    if (!java.util.Objects.equals(options, that.options)) return false;

    if (!java.util.Objects.equals(workers, that.workers)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(load,  options,  workers,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (load != null) { sb.append("load:"); sb.append(load + ","); }
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (workers != null) { sb.append("workers:"); sb.append(workers); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressCPUSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StressCPUSpecFluent<A extends StressCPUSpecFluent<A>> extends BaseFluent<A>{
  public StressCPUSpecFluent() {
  }
  
  public StressCPUSpecFluent(StressCPUSpec instance) {
    this.copyInstance(instance);
  }
  private Integer load;
  private String options;
  private Integer workers;
  
  protected void copyInstance(StressCPUSpec instance) {
    instance = (instance != null ? instance : new StressCPUSpec());
  
    if (instance != null) {
        this.withLoad(instance.getLoad());
        this.withOptions(instance.getOptions());
        this.withWorkers(instance.getWorkers());
        this.withLoad(instance.getLoad());
        this.withOptions(instance.getOptions());
        this.withWorkers(instance.getWorkers());
      }
  }
  
  public Integer getLoad() {
    return this.load;
  }
  
  public A withLoad(Integer load) {
    this.load=load; return (A) this;
  }
  
  public boolean hasLoad() {
    return this.load != null;
  }
  
  public String getOptions() {
    return this.options;
  }
  
  public A withOptions(String options) {
    this.options=options; return (A) this;
  }
  
  public boolean hasOptions() {
    return this.options != null;
  }
  
  public Integer getWorkers() {
    return this.workers;
  }
  
  public A withWorkers(Integer workers) {
    this.workers=workers; return (A) this;
  }
  
  public boolean hasWorkers() {
    return this.workers != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressCPUSpecFluent that = (StressCPUSpecFluent) o;
    if (!java.util.Objects.equals(load, that.load)) return false;
  
    if (!java.util.Objects.equals(options, that.options)) return false;
  
    if (!java.util.Objects.equals(workers, that.workers)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(load,  options,  workers,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (load != null) { sb.append("load:"); sb.append(load + ","); }
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (workers != null) { sb.append("workers:"); sb.append(workers); }
    sb.append("}");
    return sb.toString();
  }
  

}
